@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,12 +37,10 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 				     unsigned short new_count, 
 				     const std::vector<FS> & FILESYSTEMS,
 				     bool only_unformatted,
-				     Sector cylinder_size,
 				     Glib::ustring disktype )
 {
 	this ->new_count = new_count;
 	this ->selected_partition = partition;
-	this ->cylinder_size = cylinder_size ;
 
 	//copy GParted FILESYSTEMS
 	this ->FILESYSTEMS = FILESYSTEMS ;
@@ -52,8 +50,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	{
 		if ( this ->FILESYSTEMS[ t ] .filesystem == GParted::FS_UNKNOWN ||
 		     this ->FILESYSTEMS[ t ] .filesystem == GParted::FS_LVM2 ||
-		     this ->FILESYSTEMS[ t ] .filesystem == GParted::FS_LUKS ||
-		     this ->FILESYSTEMS[ t ] .filesystem == GParted::FS_BTRFS
+		     this ->FILESYSTEMS[ t ] .filesystem == GParted::FS_LUKS
 		   )
 			this ->FILESYSTEMS .erase( this->FILESYSTEMS .begin() + t ) ;
 	}
@@ -61,7 +58,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	FS fs_tmp ;
 	//add FS_UNFORMATTED
 	fs_tmp .filesystem = GParted::FS_UNFORMATTED ;
-	fs_tmp .create = GParted::FS::LIBPARTED ;
+	fs_tmp .create = FS::GPARTED ;
 	this ->FILESYSTEMS .push_back( fs_tmp ) ;
 
 	//add FS_EXTENDED
@@ -307,14 +304,17 @@ void Dialog_Partition_New::optionmenu_changed( bool type )
 	}
 
 	//set fitting resizer colors
-	//backgroundcolor..
-	color_temp .set( optionmenu_type .get_history() == 2 ? "darkgrey" : "white" ) ;
-	frame_resizer_base ->override_default_rgb_unused_color( color_temp );
-	
-	//partitioncolor..
-	color_temp .set( Utils::get_color( fs .filesystem ) ) ;
-	frame_resizer_base ->set_rgb_partition_color( color_temp ) ;
-	
+	{
+		Gdk::Color color_temp;
+		//Background color
+		color_temp.set((optionmenu_type.get_history() == 2) ? "darkgrey" : "white");
+		frame_resizer_base->override_default_rgb_unused_color(color_temp);
+
+		//Partition color
+		color_temp.set(Utils::get_color(fs.filesystem));
+		frame_resizer_base->set_rgb_partition_color(color_temp);
+	}
+
 	frame_resizer_base ->Draw_Partition() ;
 }
 
@@ -324,7 +324,7 @@ void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted )
 	//fill the file system menu with the file systems (except for extended) 
 	for ( unsigned int t = 0 ; t < FILESYSTEMS .size( ) ; t++ ) 
 	{
-		//skip extended (btrfs, luks, lvm2, and unknown removed in Set_Data())
+		//skip extended (luks, lvm2, and unknown removed in Set_Data())
 		if( FILESYSTEMS[ t ] .filesystem == GParted::FS_EXTENDED )
 			continue ;
 		menu_filesystem .items() .push_back( 
