@@ -112,6 +112,14 @@ bool reiser4::resize( const Partition & partition_new, OperationDetail & operati
 	return true ;
 }
 
+bool reiser4::move( const Partition & partition_new
+                  , const Partition & partition_old
+                  , OperationDetail & operationdetail
+                  )
+{
+	return true ;
+}
+
 bool reiser4::copy( const Glib::ustring & src_part_path, 
 		    const Glib::ustring & dest_part_path,
 		    OperationDetail & operationdetail )
